Development mode — fantastico 0.1.0-b1 documentation

### Navigation

- index
- next |
- previous |
- fantastico 0.1.0-b1 documentation »
- Getting started »

# Development mode

Fantastico framework is a web framework designed to be developers friendly. In order to simplify setup sequence, fantastico provides a standalone WSGI compatible server that can be started from command line. This server is fully compliant with WSGI standard. Below you can find some easy steps to achieve this:

1. Goto fantastico framework or project location
2. sh run_dev_server.sh

This is it. Now you have a running fantastico server on which you can test your work.

By default, Fantastico dev server starts on port 12000, but you can customize it from `fantastico.settings.BasicSettings`.

## Hot deploy

Currently, this is not implemented, but it is on todo list on short term.

## API

For more information about Fantastico development server see the API below.

class `fantastico.server.dev_server.` `DevServer`(settings_facade=<class 'fantastico.settings.SettingsFacade'>)

  This class provides a very simple wsgi http server that embeds Fantastico framework into it. As developer you can use it to simply test your new components.

  `start`(build_server=<function make_server at 0x4704848>, app=<class 'fantastico.middleware.fantastico_app.FantasticoApp'>)

    This method starts a WSGI development server. All attributes like port, hostname and protocol are read from configuration file.

  `started`

    Property used to tell if development server is started or not.

  `stop`()

    This method stops the current running server (if any available).

## Database config

Usually you will use Fantastico framework together with a database. When we develop new core features of Fantastico we use a sample database for integration. You can easily use it as well to play around:

1. Goto fantastico framework location
2. export MYSQL_PASSWD=***** (your mysql password)
3. export MYSQL_HOST=<hostname> (your mysql hostname: e.g localhost)
4. sh run_setup_db.sh

run_setup_db.sh create an initial fantastico database and a user called fantastico identified by 12345 password. After database is successfully created, it scans for all available module_setup.sql files and execute them against newly created database.

### Navigation

- index
- next |
- previous |
- fantastico 0.1.0-b1 documentation »
- Getting started »